==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/EquipmentDetails.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.COSTCODEID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTCONFIGURATIONID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGURATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLSPECIFIC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMISSIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GENERATECOUNT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYLOT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentconfigurationid",
    "equipmentconfigstatus",
    "allspecific",
    "departmentid",
    "commissiondate",
    "equipmentstatus",
    "locationid",
    "costcodeid",
    "assignedto",
    "storeid",
    "bin",
    "lotid",
    "generatecount",
    "objtype",
    "partid",
    "bylot"
})
@XmlRootElement(name = "EquipmentDetails")
public class EquipmentDetails {

    @XmlElement(name = "EQUIPMENTCONFIGURATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTCONFIGURATIONID_Type equipmentconfigurationid;
    @XmlElement(name = "EQUIPMENTCONFIGSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentconfigstatus;
    @XmlElement(name = "ALLSPECIFIC", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String allspecific;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "COMMISSIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME commissiondate;
    @XmlElement(name = "EQUIPMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type equipmentstatus;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "COSTCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected COSTCODEID_Type costcodeid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOTID_Type lotid;
    @XmlElement(name = "GENERATECOUNT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY generatecount;
    @XmlElement(name = "OBJTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String objtype;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "BYLOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bylot;

    /**
     * Obtient la valeur de la propriété equipmentconfigurationid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public EQUIPMENTCONFIGURATIONID_Type getEQUIPMENTCONFIGURATIONID() {
        return equipmentconfigurationid;
    }

    /**
     * Définit la valeur de la propriété equipmentconfigurationid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public void setEQUIPMENTCONFIGURATIONID(EQUIPMENTCONFIGURATIONID_Type value) {
        this.equipmentconfigurationid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentconfigstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTCONFIGSTATUS() {
        return equipmentconfigstatus;
    }

    /**
     * Définit la valeur de la propriété equipmentconfigstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTCONFIGSTATUS(STATUS_Type value) {
        this.equipmentconfigstatus = value;
    }

    /**
     * Obtient la valeur de la propriété allspecific.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLSPECIFIC() {
        return allspecific;
    }

    /**
     * Définit la valeur de la propriété allspecific.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLSPECIFIC(String value) {
        this.allspecific = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété commissiondate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCOMMISSIONDATE() {
        return commissiondate;
    }

    /**
     * Définit la valeur de la propriété commissiondate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCOMMISSIONDATE(DATETIME value) {
        this.commissiondate = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTSTATUS() {
        return equipmentstatus;
    }

    /**
     * Définit la valeur de la propriété equipmentstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTSTATUS(STATUS_Type value) {
        this.equipmentstatus = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété costcodeid.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Définit la valeur de la propriété costcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

    /**
     * Obtient la valeur de la propriété assignedto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Définit la valeur de la propriété assignedto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété bin.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Définit la valeur de la propriété bin.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Obtient la valeur de la propriété lotid.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Définit la valeur de la propriété lotid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Obtient la valeur de la propriété generatecount.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getGENERATECOUNT() {
        return generatecount;
    }

    /**
     * Définit la valeur de la propriété generatecount.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setGENERATECOUNT(QUANTITY value) {
        this.generatecount = value;
    }

    /**
     * Obtient la valeur de la propriété objtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Définit la valeur de la propriété objtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété bylot.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYLOT() {
        return bylot;
    }

    /**
     * Définit la valeur de la propriété bylot.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYLOT(String value) {
        this.bylot = value;
    }

}

==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/EquipmentDetails.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.COSTCODEID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTCONFIGURATIONID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGURATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLSPECIFIC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMISSIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GENERATECOUNT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYLOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTEQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentconfigurationid",
    "equipmentconfigstatus",
    "allspecific",
    "departmentid",
    "commissiondate",
    "equipmentstatus",
    "locationid",
    "costcodeid",
    "assignedto",
    "storeid",
    "bin",
    "lotid",
    "generatecount",
    "objtype",
    "partid",
    "bylot",
    "parentequipmentid",
    "dependent",
    "costrollup"
})
@XmlRootElement(name = "EquipmentDetails")
public class EquipmentDetails {

    @XmlElement(name = "EQUIPMENTCONFIGURATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTCONFIGURATIONID_Type equipmentconfigurationid;
    @XmlElement(name = "EQUIPMENTCONFIGSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentconfigstatus;
    @XmlElement(name = "ALLSPECIFIC", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String allspecific;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "COMMISSIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME commissiondate;
    @XmlElement(name = "EQUIPMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type equipmentstatus;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "COSTCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected COSTCODEID_Type costcodeid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOTID_Type lotid;
    @XmlElement(name = "GENERATECOUNT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY generatecount;
    @XmlElement(name = "OBJTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String objtype;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "BYLOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bylot;
    @XmlElement(name = "PARENTEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type parentequipmentid;
    @XmlElement(name = "DEPENDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String dependent;
    @XmlElement(name = "COSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String costrollup;

    /**
     * Obtient la valeur de la propriété equipmentconfigurationid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public EQUIPMENTCONFIGURATIONID_Type getEQUIPMENTCONFIGURATIONID() {
        return equipmentconfigurationid;
    }

    /**
     * Définit la valeur de la propriété equipmentconfigurationid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public void setEQUIPMENTCONFIGURATIONID(EQUIPMENTCONFIGURATIONID_Type value) {
        this.equipmentconfigurationid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentconfigstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTCONFIGSTATUS() {
        return equipmentconfigstatus;
    }

    /**
     * Définit la valeur de la propriété equipmentconfigstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTCONFIGSTATUS(STATUS_Type value) {
        this.equipmentconfigstatus = value;
    }

    /**
     * Obtient la valeur de la propriété allspecific.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLSPECIFIC() {
        return allspecific;
    }

    /**
     * Définit la valeur de la propriété allspecific.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLSPECIFIC(String value) {
        this.allspecific = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété commissiondate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCOMMISSIONDATE() {
        return commissiondate;
    }

    /**
     * Définit la valeur de la propriété commissiondate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCOMMISSIONDATE(DATETIME value) {
        this.commissiondate = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTSTATUS() {
        return equipmentstatus;
    }

    /**
     * Définit la valeur de la propriété equipmentstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTSTATUS(STATUS_Type value) {
        this.equipmentstatus = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété costcodeid.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Définit la valeur de la propriété costcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

    /**
     * Obtient la valeur de la propriété assignedto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Définit la valeur de la propriété assignedto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété bin.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Définit la valeur de la propriété bin.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Obtient la valeur de la propriété lotid.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Définit la valeur de la propriété lotid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Obtient la valeur de la propriété generatecount.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getGENERATECOUNT() {
        return generatecount;
    }

    /**
     * Définit la valeur de la propriété generatecount.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setGENERATECOUNT(QUANTITY value) {
        this.generatecount = value;
    }

    /**
     * Obtient la valeur de la propriété objtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Définit la valeur de la propriété objtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété bylot.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYLOT() {
        return bylot;
    }

    /**
     * Définit la valeur de la propriété bylot.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYLOT(String value) {
        this.bylot = value;
    }

    /**
     * Obtient la valeur de la propriété parentequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPARENTEQUIPMENTID() {
        return parentequipmentid;
    }

    /**
     * Définit la valeur de la propriété parentequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPARENTEQUIPMENTID(EQUIPMENTID_Type value) {
        this.parentequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété dependent.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEPENDENT() {
        return dependent;
    }

    /**
     * Définit la valeur de la propriété dependent.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEPENDENT(String value) {
        this.dependent = value;
    }

    /**
     * Obtient la valeur de la propriété costrollup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Définit la valeur de la propriété costrollup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

}
